@@ -1,6 +1,6 @@
 package AI::DecisionTree::Instance;
 BEGIN {
-  $VERSION = '0.03';
+  $VERSION = '0.04';
   @ISA = qw(DynaLoader);
 }
 
@@ -21,13 +21,10 @@ AI::DecisionTree::Instance - C-struct wrapper for training instances
 
   use AI::DecisionTree::Instance;
   
-  my $i = new AI::DecisionTree::Instance({foo => 'fooey', bar=> 'barrey'}, 'sports');
-  $i->value('foo') eq 'fooey';
-  $i->value('bar') eq 'barrey';
-  $i->result eq 'sports';
-  
-  $i->value_int(0) == 0;  # Integer versions of values and attributes
-  $i->result_int == 0;    # Integer version of result
+  my $i = new AI::DecisionTree::Instance([3,5], 7, 'this_instance');
+  $i->value_int(0) == 3;
+  $i->value_int(1) == 5;
+  $i->result_int == 7;
 
 =head1 DESCRIPTION
 
@@ -37,9 +34,11 @@ a "typical" training set with about 1000 instances, memory usage can
 be reduced by about a factor of 5 (from 43.7M to 8.2M in my test
 program).
 
-This class typically has little effect on training speed or
-data-reading speed.  It's not really a speed increaser, it's a memory
-saver.
+A fairly tight loop is also implemented that helps speed up the
+C<train()> AI::DecisionTree method by about a constant factor of 4.
+
+Please do not consider this interface stable - I change it whenever I
+have a new need in AI::DecisionTree.
 
 =head1 AUTHOR
 
@@ -47,6 +46,6 @@ Ken Williams, ken@mathforum.org
 
 =head1 SEE ALSO
 
-AI::DecisionTree, Inline
+AI::DecisionTree
 
 =cut
